@@ -24,6 +24,14 @@ def main():
     if not Path("plugin.json") in list(Path().iterdir()):
         raise Exception("The command must be run from where plugin.json is located")
 
+    # Convert path to windows/kitematic format
+    # C:\Users\user > /c/Users/user
+    build_dir = f"{build_dir.as_posix()}"
+    if ":" in build_dir:
+        build_dir = build_dir.replace(":", "")
+        if not build_dir.startswith("/"):
+            build_dir = f"/{build_dir}"
+
     volumes = {build_dir: {'bind': '/data', 'mode': 'rw'}}
     log.info(f"Will mount volumes: {volumes}")
     log.info(f"Starting docker container")
